{% load comments i18n %}
{% load url from future %}
<div id="entry-{{ object.pk }}" class="hentry{% if object.featured %} featured{% endif %}">
  {% block entry-header %}
  <div class="entry-header">
    {% block entry-title %}
    <h2 class="entry-title">
      <a href="{{ object.get_absolute_url }}" title="{{ object.title }}" rel="bookmark">
        {{ object.title }}
      </a>
    </h2>
    {% endblock %}
  </div>
  {% endblock %}

  {% block entry-body %}
  <div class="entry-body">
    {% block entry-image %}
    {% if object.image %}
    <div class="entry-image">
      <p>
        {% if continue_reading %}
        <a href="{{ object.get_absolute_url }}" title="{{ object.title }}" rel="bookmark">
          {% endif %}
          <img src="{{ object.image.url }}" alt="{{ object.title }}" class="left img-responsive" />
          {% if continue_reading %}
        </a>
        {% endif %}
      </p>
    </div>
    {% endif %}
    {% endblock %}
    {% block entry-content %}
    <div class="entry-content">
      {{ object_content|safe }}
    </div>
    {% endblock %}
    {% block continue-reading %}
    {% if continue_reading %}
    <p class="continue-reading">
      <a href="{{ object.get_absolute_url }}"
         title="{% blocktrans with object=object.title %}Continue reading {{ object }}{% endblocktrans %}"
         rel="bookmark">
        {% trans "Continue reading" %}
      </a>
    </p>
    {% endif %}
    {% endblock %}
  </div>
  {% endblock %}

  {% block entry-footer %}{% endblock %}
</div>
