{% extends "zinnia/entry_list.html" %}
{% load i18n zinnia_tags %}

{% block meta-description %}{% trans "Latest entries" %}{% endblock meta-description %}

{% block title %}{% trans "Latest entries" %}{% endblock title %}

{% block body-class %}{{ block.super }} archive index {% now "\y\e\a\r-Y \m\o\n\t\h-m \w\e\ek-W \d\a\y-d" %}{% endblock body-class %}

{% block slider %}
{% get_featured_entries template="zinnia/tags/slider_entries.html" %}
{% endblock slider %}

{% block content-related %}
{% if date_list %}
<h3>{% trans "Yearly archives" %}</h3>
<ul>
  {% for date in date_list %}
  <li>
    <a href="{% url 'zinnia_entry_archive_year' date|date:"Y" %}" rel="archives">{{ date|date:"Y" }}</a>
  </li>
  {% endfor %}
</ul>
{% endif %}
{% endblock content-related %}
