{% extends "base.html" %}

{% block title %}404 Not Found{% endblock %}

{% block content %}
<h2>404 Not Found</h2>
<p>Wir konnten die von Ihnen angeforderte Seite leider nicht finden.</p>
{% endblock %}
