{% extends "base.html" %}

{% block title %}403 Forbidden{% endblock %}

{% block content %}
<h2>403 Forbidden</h2>
<p>Wir dürfen Ihnen leider keinen Zugriff auf die angeforderte Seite gewähren.</p>
{% endblock %}
