{% extends "zinnia/entry_list.html" %}
{% load i18n %}

{% block meta-description %}{% trans "Archives" %} {{ year|date:"Y" }}{% endblock meta-description %}

{% block title %}{% trans "Archives" %} {{ year|date:"Y" }}{% endblock title %}

{% block body-class %}{{ block.super }} archive date year year-{{ year|date:"Y" }}{% endblock body-class %}

{% block content-title %}
<h1>{% trans "Archives" %} {{ year|date:"Y" }}</h1>
{% endblock content-title %}

{% block content-related %}
<h3>{% trans "Monthly archives" %}</h3>
<ul>
  {% for date in date_list %}
  <li>
    <a href="{% url 'zinnia_entry_archive_month' date|date:"Y" date|date:"m" %}" rel="archives">{{ date|date:"YEAR_MONTH_FORMAT" }}</a>
  </li>
  {% endfor %}
</ul>

{% if previous_year %}
<h3>{% trans "Previous year" %}</h3>
<p>
  <a href="{% url 'zinnia_entry_archive_year' previous_year|date:"Y" %}" rel="archives">{{ previous_year|date:"Y" }}</a>
</p>
{% endif %}
{% if next_year %}
<h3>{% trans "Next year" %}</h3>
<p>
  <a href="{% url 'zinnia_entry_archive_year' next_year|date:"Y" %}" rel="archives">{{ next_year|date:"Y" }}</a>
</p>
{% endif %}
{% endblock content-related %}
