{% extends "base.html" %}

{% block title %}400 Bad Request{% endblock %}

{% block content %}
<h2>400 Bad Request</h2>
<p>Wir konnten Ihre Anfrage nicht verstehen. Möglicherweise hat Ihr Web-Browser Mist gebaut.</p>
{% endblock %}
