{% extends "allauth:account/login.html" %}

{% load account %}
{% load i18n %}
{% load url from future %}

{% block title %}{% trans "Sign In" %}{% endblock %}

{% block content %}

<h1>{% trans "Sign In" %}</h1>

{% if socialaccount.providers %}
<p>{% blocktrans with site.name as site_name %}Please sign in with one
of your existing third party accounts. Or, <a href="{{ signup_url }}">sign up</a>
for a {{ site_name }} account and sign in below:{% endblocktrans %}</p>
{% endif %}

<div class="allauth_login_form">

{% if socialaccount.providers %}
	<ul class="socialaccount_providers">
		{% include "socialaccount/snippets/provider_list.html" with process="login" %}
	</ul>

	<div class="login-or">{% trans 'or' %}</div>

	{% include "socialaccount/snippets/login_extra.html" %}
{% else %}
	<p>{% blocktrans %}If you have not created an account yet, then please
	<a href="{{ signup_url }}">sign up</a> first.{% endblocktrans %}</p>
{% endif %}

	<form class="login" method="POST" action="{% url 'account_login' %}">
		{% csrf_token %}
		{{ form.as_p }}
		{% if redirect_field_value %}
		<input type="hidden" name="{{ redirect_field_name }}" value="{{ redirect_field_value }}" />
		{% endif %}
		<a class="button secondaryAction" href="{% url 'account_reset_password' %}">{% trans "Forgot Password?" %}</a>
		<button class="primaryAction" type="submit">{% trans "Sign In" %}</button>
	</form>

</div>{# allauth_login_form #}

{% endblock %}
